#################################################################################

#
#    Copyright (C) 2006 Utah State University, All rights reserved.
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
##################################################################################

__author__  = '''David Ray, Shane Graber'''
__docformat__ = 'plaintext'
__version__   = '$ Revision 0.0 $'[11:-2]

from AccessControl import ClassSecurityInfo
from Products.Archetypes.atapi import *
from Products.PloneBookmarklets.config import *
from Products.CMFCore.utils import UniqueObject
from Products.CMFCore.ActionProviderBase import ActionProviderBase
from OFS.SimpleItem import SimpleItem
from OFS.PropertyManager import PropertyManager
from Globals import InitializeClass
from Products.CMFCore import permissions
from Products.PageTemplates.PageTemplateFile import PageTemplateFile
    

class PloneBookmarkletsTool(UniqueObject, SimpleItem, PropertyManager, ActionProviderBase):
    """ Bookmarklets Tool """
    
    security = ClassSecurityInfo()
    __implements__ = (SimpleItem.__implements__,
                      ActionProviderBase.__implements__)

    id = 'portal_bookmarklets'
    meta_type = 'PloneBookmarkletsTool'
    title = 'Plone Bookmarklets Tool'
    plone_tool = True
    toolicon = 'tool.gif'

    _properties = PropertyManager._properties + (
        {'id':'AvailableSites', 'type':'lines', 'mode':'w'},
        {'id':'siteDelicious', 'type':'lines', 'mode':'w'},
        {'id':'siteDigg', 'type':'lines', 'mode':'w'},
        {'id':'siteYahoo', 'type':'lines', 'mode':'w'},
        {'id':'siteGoogle', 'type':'lines', 'mode':'w'},
        {'id':'siteSpurl', 'type':'lines', 'mode':'w'},
        {'id':'siteWists', 'type':'lines', 'mode':'w'},
        {'id':'siteSimpy', 'type':'lines', 'mode':'w'},
        {'id':'siteNewsvine', 'type':'lines', 'mode':'w'},
        {'id':'siteBlinklist', 'type':'lines', 'mode':'w'},
        {'id':'siteFurl', 'type':'lines', 'mode':'w'},
        {'id':'siteReddit', 'type':'lines', 'mode':'w'},
        {'id':'siteFark', 'type':'lines', 'mode':'w'},
        {'id':'siteBlogmarks', 'type':'lines', 'mode':'w'},
        {'id':'siteSmarking', 'type':'lines', 'mode':'w'},
        {'id':'siteMagnolia', 'type':'lines', 'mode':'w'},
    )

    AvailableSites   = ['siteDelicious',
                        'siteDigg',
                        'siteYahoo',
                        'siteGoogle',
                        'siteSpurl',
                        'siteWists',
                        'siteSimpy',
                        'siteNewsvine',
                        'siteBlinklist',
                        'siteFurl',
                        'siteReddit',
                        'siteFark',
                        'siteBlogmarks',
                        'siteSmarking',
                        'siteMagnolia'
                          ]
    siteDelicious      = ["del.icio.us",
                           "http://del.icio.us/post?url=URL&amp;title=ENCODED_TITLE",
                           "delicious.gif"]

    siteDigg           = ["Digg",
                          "http://digg.com/submit?phase=2&amp;url=URL&amp;title=ENCODED_TITLE",
                          "digg.gif"]

    siteYahoo          = ["Yahoo",
                          "http://myweb2.search.yahoo.com/myresults/bookmarklet?u=URL&amp;t=ENCODED_TITLE",
                          "yahoo.gif"]

    siteGoogle         = ["Google",
                          "http://www.google.com/bookmarks/mark?op=edit&amp;output=popup&amp;bkmk=URL&amp;title=ENCODED_TITLE",
                          "google.gif"]

    siteSpurl          = ["Spurl",
                          "http://www.spurl.net/spurl.php?title=ENCODED_TITLE&amp;url=URL",
                          "spurl.gif"]

    siteWists          = ["Wists",
                          "http://wists.com/r.php?c=&amp;r=URL&amp;tot;e=ENCODED_TITLE",
                          "wists.gif"]
    
    siteSimpy          = ["Simpy",
                          "http://www.simpy.com/simpy/LinkAdd.do?href=URL&amp;title=ENCODED_TITLE",
                          "simpy.gif"]
    
    siteNewsvine       = ["Newsvine",
                          "http://www.newsvine.com/_tools/seed&amp;save?u=URL&amp;h=ENCODED_TITLE",
                          "newsvine.gif"]
                          
    siteBlinklist      = ["Blinklist",
                          "http://www.blinklist.com/index.php?Action=Blink/addblink.php&amp;Description=DESCR&amp;Url=URL&amp;Title=ENCODED_TITLE",
                          "blinklist.gif"]
    
    siteFurl           = ["Furl",
                          "http://www.furl.net/storeIt.jsp?u=URL&amp;t=ENCODED_TITLE",
                          "furl.gif"]
    
    siteReddit         = ["Reddit",
                          "http://reddit.com/submit?url=URL&amp;title=ENCODED_TITLE",
                          "reddit.gif"]
    
    siteFark           = ["Fark",
                          "http://cgi.fark.com/cgi/fark/edit.pl?new_url=URL&amp;new_comment=ENCODED_TITLE&amp;linktype=",
                          "fark.gif"]
    
    siteBlogmarks      = ["Blogmarks",
                          "http://blogmarks.net/my/new.php?mini=1&amp;simple=1&amp;url=URL&amp;title=ENCODED_TITLE",
                          "blogmarks.gif"]
    
    siteSmarking       = ["Smarking",
                          "http://smarking.com/editbookmark/?url=URL",
                          "smarking.gif"]
    
    siteMagnolia       = ["Magnolia",
                          "http://ma.gnolia.com/bookmarklet/add?url=URL&amp;title=ENCODED_TITLE",
                          "magnolia.gif"]
    
                          
    manage_options = (({'label':'Overview', 'action':'manage_overview'},) +
                      PropertyManager.manage_options +
                      ActionProviderBase.manage_options)


    security.declareProtected(permissions.ManagePortal, 'manage_overview')
    manage_overview = PageTemplateFile('overview', WWW_DIR)

    
#    def __init__(self, id=None):
#        pass

    security.declareProtected(permissions.View, 'getSites')
    def getSites(self):
        """ return titles and ids for the supported licenses. """
        page = self.aq_parent
        page_url = page.absolute_url()
        page_title = page.title.replace(' ', '+')
        page_descr = page.Description()

        
        available_sites = []
        sites = []        
        
        available_sites = self.AvailableSites
        
        counter = 0
        for x in available_sites: 
            sites.append(getattr(self, x))
        return sites


InitializeClass(PloneBookmarkletsTool)



